package com.ruoyi.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import java.util.List;
import com.ruoyi.business.domain.TCkOrderdetail;

/**
 * 出库物料明细Mapper接口
 * 
 * @author wms
 * @date 2022-06-11
 */
public interface TCkOrderdetailMapper extends BaseMapper<TCkOrderdetail>
{
    /**
     * 查询出库物料明细
     * 
     * @param ckId 出库物料明细主键
     * @return 出库物料明细
     */
    public TCkOrderdetail selectTCkOrderdetailByCkId(String ckId);

    /**
     * 查询出库物料明细列表
     * 
     * @param tCkOrderdetail 出库物料明细
     * @return 出库物料明细集合
     */
    public List<TCkOrderdetail> selectTCkOrderdetailList(TCkOrderdetail tCkOrderdetail);

    /**
     * 查询工单出库任务
     *
     * @param tCkOrderdetail 出库物料明细
     * @return 出库物料明细集合
     */
    public List<TCkOrderdetail> selectMesTask(TCkOrderdetail tCkOrderdetail);

    /**
     * 新增出库物料明细
     * 
     * @param tCkOrderdetail 出库物料明细
     * @return 结果
     */
    public int insertTCkOrderdetail(TCkOrderdetail tCkOrderdetail);

    /**
     * 修改出库物料明细
     * 
     * @param tCkOrderdetail 出库物料明细
     * @return 结果
     */
    public int updateTCkOrderdetail(TCkOrderdetail tCkOrderdetail);

    /**
     * 删除出库物料明细
     * 
     * @param ckId 出库物料明细主键
     * @return 结果
     */
    public int deleteTCkOrderdetailByCkId(String ckId);

    /**
     * 批量删除出库物料明细
     * 
     * @param ckIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCkOrderdetailByCkIds(String[] ckIds);
}
